@@ -1,23 +1,26 @@
 """Liquid expression evaluator test cases."""
 
 import unittest
-from typing import NamedTuple, Any, Mapping
+
+from decimal import Decimal
+
+from typing import Any
+from typing import Mapping
+from typing import NamedTuple
 
 from liquid.environment import Environment
 from liquid.context import Context
 from liquid.stream import TokenStream
-from liquid.lex import (
-    tokenize_filtered_expression,
-    tokenize_boolean_expression,
-    tokenize_loop_expression,
-    tokenize_assignment_expression,
-)
-from liquid.parse import (
-    parse_filtered_expression,
-    parse_boolean_expression,
-    parse_assignment_expression,
-    parse_loop_expression,
-)
+
+from liquid.lex import tokenize_filtered_expression
+from liquid.lex import tokenize_boolean_expression
+from liquid.lex import tokenize_loop_expression
+from liquid.lex import tokenize_assignment_expression
+
+from liquid.parse import parse_filtered_expression
+from liquid.parse import parse_boolean_expression
+from liquid.parse import parse_assignment_expression
+from liquid.parse import parse_loop_expression
 
 
 class Case(NamedTuple):
@@ -495,6 +498,12 @@ class LiquidStatementEvalTestCase(unittest.TestCase):
                 expression="0",
                 expect=True,
             ),
+            Case(
+                description="0.0",
+                context={},
+                expression="0.0",
+                expect=True,
+            ),
             Case(
                 description="one",
                 context={},
@@ -507,6 +516,24 @@ class LiquidStatementEvalTestCase(unittest.TestCase):
                 expression="0 == false",
                 expect=False,
             ),
+            Case(
+                description="zero equals true",
+                context={},
+                expression="0 == true",
+                expect=False,
+            ),
+            Case(
+                description="0.0 equals false",
+                context={},
+                expression="0.0 == false",
+                expect=False,
+            ),
+            Case(
+                description="0.0 equals true",
+                context={},
+                expression="0.0 == true",
+                expect=False,
+            ),
             Case(
                 description="one equals true",
                 context={},
@@ -531,6 +558,12 @@ class LiquidStatementEvalTestCase(unittest.TestCase):
                 expression="0 < true",
                 expect=False,
             ),
+            Case(
+                description="0.0 is less than true",
+                context={},
+                expression="0.0 < true",
+                expect=False,
+            ),
             Case(
                 description="one is not equal true",
                 context={},
@@ -543,18 +576,54 @@ class LiquidStatementEvalTestCase(unittest.TestCase):
                 expression="0 != false",
                 expect=True,
             ),
+            Case(
+                description="0.0 is not equal false",
+                context={},
+                expression="0.0 != false",
+                expect=True,
+            ),
             Case(
                 description="false is not equal zero",
                 context={},
                 expression="false != 0",
                 expect=True,
             ),
+            Case(
+                description="false is not equal 0.0",
+                context={},
+                expression="false != 0.0",
+                expect=True,
+            ),
             Case(
                 description="false is less than string",
                 context={},
                 expression="false < 'false'",
                 expect=False,
             ),
+            Case(
+                description="decimal zero",
+                context={"n": Decimal("0")},
+                expression="n",
+                expect=True,
+            ),
+            Case(
+                description="decimal non-zero",
+                context={"n": Decimal("1")},
+                expression="n",
+                expect=True,
+            ),
+            Case(
+                description="decimal zero equals false",
+                context={"n": Decimal("0")},
+                expression="n == false",
+                expect=False,
+            ),
+            Case(
+                description="decimal zero equals true",
+                context={"n": Decimal("0")},
+                expression="n == true",
+                expect=False,
+            ),
         ]
 
         self._test(test_cases, tokenize_boolean_expression, parse_boolean_expression)
